import type { ReadingLog } from "@utils/ReadingLog";
import { Command } from "./Command";
import type { Storage } from "@utils/Storage";
import { Notice, type App } from "obsidian";
import { TextSuggestModal } from "@ui/modals/TextSuggestModal";

function basename(path: string) {
	return path.split("/").pop()!;
}

export class RestoreReadingLogBackupCommand extends Command {
	constructor(
		private readonly app: App,
		private readonly storage: Storage,
		private readonly readingLog: ReadingLog
	) {
		super("restore-reading-log-backup", "Restore Reading Log Backup");
	}

	async callback() {
		let items = await this.storage.listFiles();

		items = items
			.map((f) => basename(f))
			.filter(
				(f) =>
					f.startsWith("reading-log-backup_") && f.endsWith(".json")
			);

		const backupPath = await TextSuggestModal.createAndOpen(
			this.app,
			items
		);
		if (backupPath) {
			await this.readingLog.load(backupPath);
			await this.readingLog.save();
		} else {
			new Notice("No backup file selected.");
		}
	}
}
